@@ -92,7 +92,7 @@ namespace gnote {
     : utils::ForcedPresentWindow(_("Search All Notes"))
     , m_manager(m)
     , m_menubar(NULL)
-    , m_find_combo(Gtk::ListStore::create(m_find_combo_columns), 0)
+    , m_find_combo(Glib::RefPtr<Gtk::TreeModel>::cast_static(Gtk::ListStore::create(m_find_combo_columns)), true)
     , m_clear_search_button(Gtk::Stock::CLEAR)
     , m_case_sensitive(_("C_ase Sensitive"), true)
     , m_content_vbox(false, 0)
@@ -116,6 +116,7 @@ namespace gnote {
     label->property_xalign() = 1;
 
     label->set_mnemonic_widget(m_find_combo);
+    m_find_combo.set_entry_text_column(0);
     m_find_combo.signal_changed()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_entry_changed));
     m_find_combo.get_entry()->set_activates_default(false);
@@ -162,12 +163,12 @@ namespace gnote {
     m_tree = manage(m_tree);
     m_tree->show ();
 
-    m_status_bar.set_has_resize_grip(true);
+    set_has_resize_grip(true);
     m_status_bar.show();
 
     // Update on changes to notes
-    m.signal_note_deleted.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_deleted));
-    m.signal_note_added.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_added));
+    m.signal_note_deleted.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notes_changed));
+    m.signal_note_added.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notes_changed));
     m.signal_note_renamed.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_renamed));
     m.signal_note_saved.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_saved));
 
@@ -176,13 +177,6 @@ namespace gnote {
 
     m_matches_window.set_shadow_type(Gtk::SHADOW_IN);
 
-    // Reign in the window size if there are notes with long
-    // names, or a lot of notes...
-
-    int h, w;
-    m_tree->get_size_request (h,w);
-    m_matches_window.set_size_request(std::min(h, 420), std::min(w, 480));
-                        
     m_matches_window.property_hscrollbar_policy() = Gtk::POLICY_AUTOMATIC;
     m_matches_window.property_vscrollbar_policy() = Gtk::POLICY_AUTOMATIC;
     m_matches_window.add (*m_tree);
@@ -221,8 +215,7 @@ namespace gnote {
     notebooks::NotebookManager::instance().signal_note_removed_from_notebook()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_removed_from_notebook));
                         
-    Gtk::Main::signal_quit()
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_exiting_event));
+    Gnote::obj().signal_quit.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_exiting_event));
 
   }
 
@@ -343,7 +336,7 @@ namespace gnote {
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_released));
     m_tree->signal_key_press_event().connect(
       sigc::mem_fun(*this,
-                    &NoteRecentChanges::on_treeview_key_pressed));
+                    &NoteRecentChanges::on_treeview_key_pressed), false);
     m_tree->signal_drag_data_get().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_drag_data_get));
 
@@ -354,6 +347,7 @@ namespace gnote {
 
     Gtk::TreeViewColumn *title = manage(new Gtk::TreeViewColumn ());
     title->set_title(_("Note"));
+    title->set_min_width(150);
     title->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
     title->set_expand(true);
     title->set_resizable(true);
@@ -366,7 +360,7 @@ namespace gnote {
     static_cast<Gtk::CellRendererText*>(renderer)->property_ellipsize() = Pango::ELLIPSIZE_END;
     title->pack_start (*renderer, true);
     title->add_attribute (*renderer, "text", 1 /* title */);
-    title->set_sort_column_id(1); /* title */
+    title->set_sort_column(1); /* title */
     title->set_sort_indicator(false);
     title->set_reorderable(false);
     title->set_sort_order(Gtk::SORT_ASCENDING);
@@ -382,7 +376,7 @@ namespace gnote {
     renderer->property_xalign() = 1.0;
     change->pack_start (*renderer, false);
     change->add_attribute (*renderer, "text", 2 /* change date */);
-    change->set_sort_column_id(2); /* change date */
+    change->set_sort_column(2); /* change date */
     change->set_sort_indicator(false);
     change->set_reorderable(false);
     change->set_sort_order(Gtk::SORT_DESCENDING);
@@ -390,42 +384,6 @@ namespace gnote {
     m_tree->append_column (*change);
   }
 
-  void NoteRecentChanges::add_note(const Note::Ptr & note)
-  {
-    std::string nice_date =
-      utils::get_pretty_print_date(note->change_date(), true);
-    Gtk::TreeIter iter = m_store->append();
-    iter->set_value(m_column_types.icon, s_note_icon);
-    iter->set_value(m_column_types.title, note->get_title());
-    iter->set_value(m_column_types.change_date, nice_date);
-    iter->set_value(m_column_types.note, note);
-  }
-
-  void NoteRecentChanges::delete_note(const Note::Ptr & note)
-  {
-    Gtk::TreeModel::Children rows = m_store->children();
-
-    for (Gtk::TreeModel::iterator iter = rows.begin();
-         rows.end() != iter; iter++) {
-      if (note == iter->get_value(m_column_types.note)) {
-        m_store->erase(iter);
-        break;
-      }
-    }
-  }
-
-  void NoteRecentChanges::rename_note(const Note::Ptr & note)
-  {
-    Gtk::TreeModel::Children rows = m_store->children();
-
-    for (Gtk::TreeModel::iterator iter = rows.begin();
-         rows.end() != iter; iter++) {
-      if (note == iter->get_value(m_column_types.note)) {
-        iter->set_value(m_column_types.title, note->get_title());
-        break;
-      }
-    }
-  }
 
   void NoteRecentChanges::update_results()
   {
@@ -470,7 +428,7 @@ namespace gnote {
     if (sort_column >= 0) {
       // Set the sort column after loading data, since we
       // don't want to resort on every append.
-      m_store_sort->set_sort_column_id (sort_column, sort_type);
+      m_store_sort->set_sort_column(sort_column, sort_type);
     }
 
     // Restore the previous selection
@@ -518,7 +476,7 @@ namespace gnote {
         m_current_matches.clear ();
         m_store_filter->refilter ();
         update_total_note_count (m_store_sort->children().size());
-        if (m_tree->is_realized()) {
+        if (m_tree->get_realized()) {
           m_tree->scroll_to_point (0, 0);
         }
         return;
@@ -564,7 +522,7 @@ namespace gnote {
       m_matches_column->set_cell_data_func (
         *renderer,
         sigc::mem_fun(*this, &NoteRecentChanges::matches_column_data_func));
-      m_matches_column->set_sort_column_id(4);
+      m_matches_column->set_sort_column(4);
       m_matches_column->set_sort_indicator(true);
       m_matches_column->set_reorderable(false);
       m_matches_column->set_sort_order(Gtk::SORT_DESCENDING);
@@ -573,7 +531,7 @@ namespace gnote {
                                   sigc::mem_fun(*this, &NoteRecentChanges::compare_search_hits));
 
       m_tree->append_column (*m_matches_column);
-      m_store_sort->set_sort_column_id (4, Gtk::SORT_DESCENDING);
+      m_store_sort->set_sort_column(4, Gtk::SORT_DESCENDING);
     }
   }
 
@@ -586,7 +544,7 @@ namespace gnote {
     m_tree->remove_column (*m_matches_column);
     m_matches_column = NULL;
 
-    m_store_sort->set_sort_column_id (2, Gtk::SORT_DESCENDING);
+    m_store_sort->set_sort_column(2, Gtk::SORT_DESCENDING);
   }
 
 
@@ -606,7 +564,11 @@ namespace gnote {
         = m_current_matches.find(note->uri());
       if (miter != m_current_matches.end()) {
         match_count = miter->second;
-        if (match_count > 0) {
+        if(match_count == INT_MAX) {
+          //TRANSLATORS: search found a match in note title
+          match_str = _("Title match");
+        }
+        else if (match_count > 0) {
           const char * fmt;
           fmt = ngettext("%1% match", "%1% matches", match_count);
           match_str = str(boost::format(fmt) % match_count);
@@ -743,20 +705,14 @@ namespace gnote {
     perform_search ();
   }
 
-  void NoteRecentChanges::on_note_added(const Note::Ptr & note)
+  void NoteRecentChanges::on_notes_changed(const Note::Ptr &)
   {
-    add_note(note);
+    update_results ();
   }
 
-  void NoteRecentChanges::on_note_deleted(const Note::Ptr & note)
+  void NoteRecentChanges::on_note_renamed(const Note::Ptr&, const std::string&)
   {
-    delete_note(note);
-  }
-
-  void NoteRecentChanges::on_note_renamed(const Note::Ptr & note,
-                                          const std::string &)
-  {
-    rename_note(note);
+    update_results ();
   }
 
   void NoteRecentChanges::on_note_saved(const Note::Ptr&)
@@ -773,7 +729,7 @@ namespace gnote {
       return;
     }
                   
-    std::vector<std::string> uris;
+    std::vector<Glib::ustring> uris;
     for(Note::List::const_iterator iter = selected_notes.begin();
         iter != selected_notes.end(); ++iter) {
 
@@ -790,7 +746,7 @@ namespace gnote {
     }
   }
 
-  void NoteRecentChanges::on_notebook_row_edited(const Glib::ustring& tree_path,
+  void NoteRecentChanges::on_notebook_row_edited(const Glib::ustring& /*tree_path*/,
                                                  const Glib::ustring& new_text)
   {
     if (notebooks::NotebookManager::instance().notebook_exists(new_text) ||
@@ -827,7 +783,7 @@ namespace gnote {
       am ["OpenNoteAction"]->property_sensitive() = false;
       am ["DeleteNoteAction"]->property_sensitive() = false;
     } 
-    else if (selected_notes.size() == 1) {
+    else if (selected_notes.size() > 1) {
       am ["OpenNoteAction"]->property_sensitive() = true;
       am ["DeleteNoteAction"]->property_sensitive() = true;
     } 
@@ -902,8 +858,7 @@ namespace gnote {
       if (m_tree->get_selection()->is_selected(dest_path) 
           && (ev->state & (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK)) == 0) {
         if (column && (ev->button == 1)) {
-          Glib::ListHandle<Gtk::CellRenderer *> renderers = column->get_cell_renderers();
-          Gtk::CellRenderer *renderer = *renderers.begin();
+          Gtk::CellRenderer *renderer = column->get_first_cell();
           Gdk::Rectangle background_area;
           m_tree->get_background_area (dest_path, *column, background_area);
           Gdk::Rectangle cell_area;
@@ -979,7 +934,7 @@ namespace gnote {
   bool NoteRecentChanges::on_treeview_key_pressed(GdkEventKey * ev)
   {
     switch (ev->keyval) {
-    case GDK_Menu:
+    case GDK_KEY_Menu:
     {
       // Pop up the context menu if a note is selected
       Note::List selected_notes = get_selected_notes();
@@ -992,6 +947,11 @@ namespace gnote {
       }
       break;
     }
+    case GDK_KEY_Return:
+    case GDK_KEY_KP_Enter:
+      // Open all selected notes
+      on_open_note();
+      return true;
     default:
       break;
     }
@@ -1040,13 +1000,13 @@ namespace gnote {
 
     const Glib::RefPtr<Gtk::TreeSelection> selection
                                              = tree->get_selection();
-    const std::list<Gtk::TreePath> selected_rows
+    const std::vector<Gtk::TreePath> selected_rows
                                      = selection->get_selected_rows();
     if (selected_rows.empty())
       return;
 
     const Gtk::TreePath & dest_path = selected_rows.front();
-    const std::list<Gtk::TreeViewColumn *> columns
+    const std::vector<Gtk::TreeViewColumn *> columns
                                              = tree->get_columns();
     Gdk::Rectangle cell_rect;
     tree->get_cell_area (dest_path, *columns.front(), cell_rect);
@@ -1060,9 +1020,9 @@ namespace gnote {
   {
     Note::List selected_notes;
           
-    Glib::ListHandle<Gtk::TreePath, Gtk::TreePath_Traits> selected_rows =
+    std::vector<Gtk::TreePath> selected_rows =
       m_tree->get_selection()->get_selected_rows ();
-    for(Glib::ListHandle<Gtk::TreePath, Gtk::TreePath_Traits>::const_iterator iter
+    for(std::vector<Gtk::TreePath>::const_iterator iter
           = selected_rows.begin(); iter != selected_rows.end(); ++iter) {
       Note::Ptr note = get_note (*iter);
       if (!note) {
@@ -1087,10 +1047,9 @@ namespace gnote {
   void NoteRecentChanges::on_open_note()
   {
     Note::List selected_notes = get_selected_notes ();
-    if (selected_notes.size() != 1)
-      return;
-                  
-    selected_notes.front()->get_window()->present();
+    for(Note::List::iterator iter = selected_notes.begin(); iter != selected_notes.end(); ++iter) {
+      (*iter)->get_window()->present();
+    }
   }
 
   void NoteRecentChanges::on_delete_note()
@@ -1153,7 +1112,7 @@ namespace gnote {
   bool NoteRecentChanges::on_key_pressed(GdkEventKey * ev)
   {
     switch (ev->keyval) {
-    case GDK_Escape:
+    case GDK_KEY_Escape:
       // Allow Escape to close the window
       on_close_window ();
       break;
@@ -1416,8 +1375,8 @@ namespace gnote {
         allow_edit = true;
       }
 
-      Glib::ListHandle<Gtk::CellRenderer*> renderers = m_notebooksTree->get_column(0)->get_cell_renderers();
-      for (Glib::ListHandle<Gtk::CellRenderer*>::iterator renderer = renderers.begin();
+      std::vector<Gtk::CellRenderer*> renderers = m_notebooksTree->get_column(0)->get_cells();
+      for (std::vector<Gtk::CellRenderer*>::iterator renderer = renderers.begin();
            renderer != renderers.end(); ++renderer) {
         Gtk::CellRendererText *text_rederer = dynamic_cast<Gtk::CellRendererText*>(*renderer);
         if (text_rederer) {
@@ -1543,7 +1502,7 @@ namespace gnote {
   bool NoteRecentChanges::on_notebooks_key_pressed(GdkEventKey * ev)
   {
     switch (ev->keyval) {
-    case GDK_Menu:
+    case GDK_KEY_Menu:
     {
       // Pop up the context menu if a notebook is selected
       notebooks::Notebook::Ptr notebook = get_selected_notebook ();
@@ -1606,25 +1565,26 @@ namespace gnote {
 
     get_position(x, y);
     get_size(width, height);
-     
-    Preferences & prefs(Preferences::obj());
-    prefs.set<int> (Preferences::SEARCH_WINDOW_X_POS, x);
-    prefs.set<int> (Preferences::SEARCH_WINDOW_Y_POS, y);
-    prefs.set<int> (Preferences::SEARCH_WINDOW_WIDTH, width);
-    prefs.set<int> (Preferences::SEARCH_WINDOW_HEIGHT, height);
-    prefs.set<int> (Preferences::SEARCH_WINDOW_SPLITTER_POS, 
-                    m_hpaned.get_position());
+
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE);
+    settings->set_int(Preferences::SEARCH_WINDOW_X_POS, x);
+    settings->set_int(Preferences::SEARCH_WINDOW_Y_POS, y);
+    settings->set_int(Preferences::SEARCH_WINDOW_WIDTH, width);
+    settings->set_int(Preferences::SEARCH_WINDOW_HEIGHT, height);
+    settings->set_int(Preferences::SEARCH_WINDOW_SPLITTER_POS, m_hpaned.get_position());
   }
         
    
   void NoteRecentChanges::restore_position()
   {
-    Preferences & prefs(Preferences::obj());
-    int x = prefs.get<int> (Preferences::SEARCH_WINDOW_X_POS);
-    int y = prefs.get<int> (Preferences::SEARCH_WINDOW_Y_POS);
-    int width = prefs.get<int> (Preferences::SEARCH_WINDOW_WIDTH);
-    int height = prefs.get<int> (Preferences::SEARCH_WINDOW_HEIGHT);
-    int pos = prefs.get<int> (Preferences::SEARCH_WINDOW_SPLITTER_POS);
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE);
+    int x = settings->get_int(Preferences::SEARCH_WINDOW_X_POS);
+    int y = settings->get_int(Preferences::SEARCH_WINDOW_Y_POS);
+    int width = settings->get_int(Preferences::SEARCH_WINDOW_WIDTH);
+    int height = settings->get_int(Preferences::SEARCH_WINDOW_HEIGHT);
+    int pos = settings->get_int(Preferences::SEARCH_WINDOW_SPLITTER_POS);
 
     if((width == 0) || (height == 0)) {
       return;
@@ -1638,10 +1598,9 @@ namespace gnote {
   }
 
 
-  bool NoteRecentChanges::on_exiting_event()
+  void NoteRecentChanges::on_exiting_event()
   {
     save_position();
-    return false;
   }
 
 }
