@@ -137,7 +137,7 @@ namespace gnote {
     get_buffer()->remove_tag (m_title_tag, get_title_end(), end);
       
     //In the case of large copy and paste operations, show the end of the block
-    get_window()->editor()->scroll_mark_onscreen (get_buffer()->get_insert());
+    get_window()->editor()->scroll_to (get_buffer()->get_insert());
   }
   
 
@@ -296,9 +296,11 @@ namespace gnote {
 
   void NoteSpellChecker::on_note_opened ()
   {
-    Preferences::obj().signal_setting_changed()
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE);
+    settings->signal_changed()
       .connect(sigc::mem_fun(*this, &NoteSpellChecker::on_enable_spellcheck_changed));
-    if(Preferences::obj().get<bool>(Preferences::ENABLE_SPELLCHECKING)) {
+    if(settings->get_boolean(Preferences::ENABLE_SPELLCHECKING)) {
       attach ();
     }
   }
@@ -336,16 +338,15 @@ namespace gnote {
   }
   
 
-  void NoteSpellChecker::on_enable_spellcheck_changed(Preferences *, GConfEntry * entry)
+  void NoteSpellChecker::on_enable_spellcheck_changed(const Glib::ustring & key)
   {
-    const char * key = gconf_entry_get_key(entry);
-    
-    if (strcmp(key, Preferences::ENABLE_SPELLCHECKING) != 0) {
+    if (key != Preferences::ENABLE_SPELLCHECKING) {
       return;
     }
-    GConfValue *value = gconf_entry_get_value(entry);
+    bool value = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(key);
     
-    if (gconf_value_get_bool(value)) {
+    if (value) {
       attach ();
     } 
     else {
@@ -443,10 +444,8 @@ namespace gnote {
       sigc::mem_fun(*this, &NoteUrlWatcher::on_button_press), false);
     editor->signal_populate_popup().connect(
       sigc::mem_fun(*this, &NoteUrlWatcher::on_populate_popup));
-#ifdef HAVE_CLASS_GTK__WIDGET_SIGNAL_POPUP_MENU
     editor->signal_popup_menu().connect(
       sigc::mem_fun(*this, &NoteUrlWatcher::on_popup_menu), false);
-#endif
   }
 
   std::string NoteUrlWatcher::get_url(const Gtk::TextIter & start, const Gtk::TextIter & end)
@@ -744,7 +743,7 @@ namespace gnote {
   }
 
 
-  void NoteLinkWatcher::on_note_renamed(const Note::Ptr& renamed, const std::string& old_title)
+  void NoteLinkWatcher::on_note_renamed(const Note::Ptr& renamed, const std::string& /*old_title*/)
   {
     if (renamed == get_note()) {
       return;
@@ -763,22 +762,20 @@ namespace gnote {
   {
     // Some of these checks should be replaced with fixes to
     // TitleTrie.FindMatches, probably.
-    if (hit.value().expired()) {
-      DBG_OUT("DoHighlight: null pointer error for '%s'." , hit.key().c_str());
+    if (hit.value.expired()) {
+      DBG_OUT("DoHighlight: null pointer error for '%s'." , hit.key.c_str());
       return;
     }
       
-    if (!manager().find(hit.key())) {
-      DBG_OUT ("DoHighlight: '%s' links to non-existing note." ,
-               hit.key().c_str());
+    if (!manager().find(hit.key)) {
+      DBG_OUT ("DoHighlight: '%s' links to non-existing note." , hit.key.c_str());
       return;
     }
       
-    Note::Ptr hit_note(hit.value());
+    Note::Ptr hit_note(hit.value);
 
-    if (sharp::string_to_lower(hit.key()) != sharp::string_to_lower(hit_note->get_title())) { // == 0 if same string
-      DBG_OUT ("DoHighlight: '%s' links wrongly to note '%s'." ,
-               hit.key().c_str(),
+    if (sharp::string_to_lower(hit.key) != sharp::string_to_lower(hit_note->get_title())) { // == 0 if same string  
+      DBG_OUT ("DoHighlight: '%s' links wrongly to note '%s'." , hit.key.c_str(), 
                hit_note->get_title().c_str());
       return;
     }
@@ -787,10 +784,10 @@ namespace gnote {
       return;
 
     Gtk::TextIter title_start = start;
-    title_start.forward_chars (hit.start());
+    title_start.forward_chars (hit.start);
 
     Gtk::TextIter title_end = start;
-    title_end.forward_chars (hit.end());
+    title_end.forward_chars (hit.end);
 
     // Only link against whole words/phrases
     if ((!title_start.starts_word () && !title_start.starts_sentence ()) ||
@@ -799,12 +796,12 @@ namespace gnote {
     }
 
     // Don't create links inside URLs
-    if (title_start.has_tag (m_url_tag)) {
+    if(get_note()->get_tag_table()->has_link_tag(title_start)) {
       return;
     }
 
     DBG_OUT ("Matching Note title '%s' at %d-%d...",
-             hit.key().c_str(), hit.start(), hit.end());
+             hit.key.c_str(), hit.start, hit.end);
 
     get_buffer()->remove_tag (m_broken_link_tag, title_start, title_end);
     get_buffer()->apply_tag (m_link_tag, title_start, title_end);
@@ -882,7 +879,7 @@ namespace gnote {
   }
 
 
-  void NoteLinkWatcher::on_apply_tag(const Glib::RefPtr<Gtk::TextBuffer::Tag> & tag,
+  void NoteLinkWatcher::on_apply_tag(const Glib::RefPtr<Gtk::TextBuffer::Tag> & /*tag*/,
                                      const Gtk::TextIter & start, const Gtk::TextIter &end)
   {
     std::string link_name = start.get_text (end);
@@ -957,26 +954,27 @@ namespace gnote {
 
   void NoteWikiWatcher::on_note_opened ()
   {
-    if ((bool) Preferences::obj().get<bool> (Preferences::ENABLE_WIKIWORDS)) {
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(
+        Preferences::SCHEMA_GNOTE);
+    if (settings->get_boolean(Preferences::ENABLE_WIKIWORDS)) {
       m_on_insert_text_cid = get_buffer()->signal_insert().connect(
         sigc::mem_fun(*this, &NoteWikiWatcher::on_insert_text));
       m_on_delete_range_cid = get_buffer()->signal_erase().connect(
         sigc::mem_fun(*this, &NoteWikiWatcher::on_delete_range));
     }
-    Preferences::obj().signal_setting_changed()
+    settings->signal_changed()
       .connect(sigc::mem_fun(*this, &NoteWikiWatcher::on_enable_wikiwords_changed));
   }
 
 
-  void NoteWikiWatcher::on_enable_wikiwords_changed(Preferences *, GConfEntry * entry)
+  void NoteWikiWatcher::on_enable_wikiwords_changed(const Glib::ustring & key)
   {
-    const char * key = gconf_entry_get_key(entry);
-    
-    if (strcmp(key, Preferences::ENABLE_WIKIWORDS) != 0) {
+    if(key != Preferences::ENABLE_WIKIWORDS) {
       return;
     }
-    GConfValue * value = gconf_entry_get_value(entry);
-    if (gconf_value_get_bool(value)) {
+    bool value = Preferences::obj().get_schema_settings(
+        Preferences::SCHEMA_GNOTE)->get_boolean(key);
+    if (value) {
       m_on_insert_text_cid = get_buffer()->signal_insert().connect(
         sigc::mem_fun(*this, &NoteWikiWatcher::on_insert_text));
       m_on_delete_range_cid = get_buffer()->signal_erase().connect(
@@ -1010,13 +1008,17 @@ namespace gnote {
       Glib::ustring segment(p, p + len);
       start_cpy.forward_chars (segment.length());
 
-      DBG_OUT("Highlighting wikiword: '%s' at offset %d",
-              match.c_str(), segment.length());
-
       end = start_cpy;
       segment = match;
       end.forward_chars (segment.length());
 
+      if(get_note()->get_tag_table()->has_link_tag(start_cpy)) {
+        break;
+      }
+
+      DBG_OUT("Highlighting wikiword: '%s' at offset %d",
+              match.c_str(), segment.length());
+
       if (!manager().find(match)) {
         get_buffer()->apply_tag (m_broken_link_tag, start_cpy, end);
       }
@@ -1041,14 +1043,14 @@ namespace gnote {
   ////////////////////////////////////////////////////////////////////////
 
   bool MouseHandWatcher::s_static_inited = false;
-  Gdk::Cursor MouseHandWatcher::s_normal_cursor;
-  Gdk::Cursor MouseHandWatcher::s_hand_cursor;
+  Glib::RefPtr<Gdk::Cursor> MouseHandWatcher::s_normal_cursor;
+  Glib::RefPtr<Gdk::Cursor> MouseHandWatcher::s_hand_cursor;
 
   void MouseHandWatcher::_init_static()
   {
     if(!s_static_inited) {
-      s_normal_cursor = Gdk::Cursor(Gdk::XTERM);
-      s_hand_cursor = Gdk::Cursor(Gdk::HAND2);
+      s_normal_cursor = Gdk::Cursor::create(Gdk::XTERM);
+      s_hand_cursor = Gdk::Cursor::create(Gdk::HAND2);
       s_static_inited = true;
     }
   }
@@ -1089,10 +1091,10 @@ namespace gnote {
     bool retval = false;
 
     switch (ev->keyval) {
-    case GDK_Shift_L:
-    case GDK_Shift_R:
-    case GDK_Control_L:
-    case GDK_Control_R:
+    case GDK_KEY_Shift_L:
+    case GDK_KEY_Shift_R:
+    case GDK_KEY_Control_L:
+    case GDK_KEY_Control_R:
     {
       // Control or Shift when hovering over a link
       // swiches to a bar cursor...
@@ -1104,8 +1106,8 @@ namespace gnote {
       win->set_cursor(s_normal_cursor);
       break;
     }
-    case GDK_Return:
-    case GDK_KP_Enter:
+    case GDK_KEY_Return:
+    case GDK_KEY_KP_Enter:
     {
       Gtk::TextIter iter = get_buffer()->get_iter_at_mark (get_buffer()->get_insert());
 
@@ -1136,10 +1138,10 @@ namespace gnote {
   {
     bool retval = false;
     switch (ev->keyval) {
-    case GDK_Shift_L:
-    case GDK_Shift_R:
-    case GDK_Control_L:
-    case GDK_Control_R:
+    case GDK_KEY_Shift_L:
+    case GDK_KEY_Shift_R:
+    case GDK_KEY_Control_L:
+    case GDK_KEY_Control_R:
     {
       if (!m_hovering_on_link)
         break;
